@@ -27,21 +27,10 @@ from gpdefs import *
 
 try:
     gettext.bindtextdomain(GETTEXT_PACKAGE, GP_LOCALEDIR)
-    _ = lambda s: gettext.dgettext(GETTEXT_PACKAGE, s);
+    _ = lambda s: gettext.dgettext(GETTEXT_PACKAGE, s)
 except:
     _ = lambda s: s
 
-ui_str = """
-<ui>
-  <menubar name="MenuBar">
-    <menu name="ToolsMenu" action="Tools">
-      <placeholder name="ToolsOps_2">
-        <menuitem name="ColorPicker" action="ColorPicker"/>
-      </placeholder>
-    </menu>
-  </menubar>
-</ui>
-"""
 
 class ColorHelper:
 
@@ -57,7 +46,7 @@ class ColorHelper:
 
             if char.lower() not in \
                     ('0', '1', '2', '3', '4', '5', '6', '7', '8', '9',
-                    'a', 'b', 'c', 'd', 'e', 'f'):
+                     'a', 'b', 'c', 'd', 'e', 'f'):
                 return
 
             if not next_char(iter):
@@ -127,9 +116,26 @@ class ColorHelper:
         else:
             return None
 
+
+class ColorPickerAppActivatable(GObject.Object, Gedit.AppActivatable):
+
+    app = GObject.Property(type=Gedit.App)
+
+    def __init__(self):
+        GObject.Object.__init__(self)
+
+    def do_activate(self):
+        self.menu_ext = self.extend_menu("tools-section")
+        item = Gio.MenuItem.new(_("Pick _Color..."), "win.colorpicker")
+        self.menu_ext.prepend_menu_item(item)
+
+    def do_deactivate(self):
+        self.menu_ext = None
+
+
 class ColorPickerWindowActivatable(GObject.Object, Gedit.WindowActivatable):
 
-    window = GObject.property(type=Gedit.Window)
+    window = GObject.Property(type=Gedit.Window)
 
     def __init__(self):
         GObject.Object.__init__(self)
@@ -137,41 +143,30 @@ class ColorPickerWindowActivatable(GObject.Object, Gedit.WindowActivatable):
         self._color_helper = ColorHelper()
 
     def do_activate(self):
-        self._insert_menu()
+        action = Gio.SimpleAction(name="colorpicker")
+        action.connect('activate', lambda a, p: self.on_color_picker_activate())
+        self.window.add_action(action)
         self._update()
 
     def do_deactivate(self):
-        self._remove_menu()
+        self.window.remove_action("colorpicker")
 
     def do_update_state(self):
         self._update()
 
     def _update(self):
         tab = self.window.get_active_tab()
-        self.window.lookup_action("colorpicker").set_enabled(tab != None)
+        self.window.lookup_action("colorpicker").set_enabled(tab is not None)
 
         if not tab and self._dialog and \
                 self._dialog.get_transient_for() == self.window:
             self._dialog.response(Gtk.ResponseType.CLOSE)
 
-    def _insert_menu(self):
-        action = Gio.SimpleAction(name="colorpicker")
-        action.connect('activate', lambda a, p: self.on_color_picker_activate())
-        self.window.add_action(action)
-
-        self.menu = self.extend_gear_menu("ext9")
-        item = Gio.MenuItem.new(_("Pick _Color..."), "win.colorpicker")
-        self.menu.prepend_menu_item(item)
-
-    def _remove_menu(self):
-        self.window.remove_action("colorpicker")
-
     # Signal handlers
 
     def on_color_picker_activate(self):
         if not self._dialog:
             self._dialog = Gtk.ColorChooserDialog.new(_('Pick Color'), self.window)
-
             self._dialog.connect_after('response', self.on_dialog_response)
 
         rgba_str = self._color_helper.get_current_color(self.window.get_active_document(), False)
@@ -190,8 +185,8 @@ class ColorPickerWindowActivatable(GObject.Object, Gedit.WindowActivatable):
             rgba = dialog.get_rgba()
 
             self._color_helper.insert_color(self.window.get_active_view(),
-                                            "%02x%02x%02x" % (self._color_helper.scale_color_component(rgba.red), \
-                                                              self._color_helper.scale_color_component(rgba.green), \
+                                            "%02x%02x%02x" % (self._color_helper.scale_color_component(rgba.red),
+                                                              self._color_helper.scale_color_component(rgba.green),
                                                               self._color_helper.scale_color_component(rgba.blue)))
         else:
             self._dialog.destroy()
@@ -200,7 +195,7 @@ class ColorPickerWindowActivatable(GObject.Object, Gedit.WindowActivatable):
 
 class ColorPickerViewActivatable(GObject.Object, Gedit.ViewActivatable):
 
-    view = GObject.property(type=Gedit.View)
+    view = GObject.Property(type=Gedit.View)
 
     def __init__(self):
         GObject.Object.__init__(self)
@@ -269,8 +264,8 @@ class ColorPickerViewActivatable(GObject.Object, Gedit.ViewActivatable):
         rgba = color_button.get_rgba()
 
         self._color_helper.insert_color(self.view,
-                                        "%02x%02x%02x" % (self._color_helper.scale_color_component(rgba.red), \
-                                                          self._color_helper.scale_color_component(rgba.green), \
+                                        "%02x%02x%02x" % (self._color_helper.scale_color_component(rgba.red),
+                                                          self._color_helper.scale_color_component(rgba.green),
                                                           self._color_helper.scale_color_component(rgba.blue)))
 
 # ex:ts=4:et:
