@@ -31,7 +31,7 @@ except:
 
 
 class JoinLinesAppActivatable(GObject.Object, Gedit.AppActivatable):
-    app = GObject.property(type=Gedit.App)
+    app = GObject.Property(type=Gedit.App)
 
     def __init__(self):
         GObject.Object.__init__(self)
@@ -47,7 +47,7 @@ class JoinLinesAppActivatable(GObject.Object, Gedit.AppActivatable):
 
 class JoinLinesWindowActivatable(GObject.Object, Gedit.WindowActivatable):
 
-    window = GObject.property(type=Gedit.Window)
+    window = GObject.Property(type=Gedit.Window)
 
     def __init__(self):
         GObject.Object.__init__(self)
@@ -84,7 +84,7 @@ class JoinLinesWindowActivatable(GObject.Object, Gedit.WindowActivatable):
 
 class JoinLinesViewActivatable(GObject.Object, Gedit.ViewActivatable):
 
-    view = GObject.property(type=Gedit.View)
+    view = GObject.Property(type=Gedit.View)
 
     def __init__(self):
         GObject.Object.__init__(self)
@@ -121,8 +121,6 @@ class JoinLinesViewActivatable(GObject.Object, Gedit.ViewActivatable):
         if doc is None:
             return
 
-        doc.begin_user_action()
-
         # If there is a selection use it, otherwise join the
         # next line
         try:
@@ -132,27 +130,7 @@ class JoinLinesViewActivatable(GObject.Object, Gedit.ViewActivatable):
             end = start.copy()
             end.forward_line()
 
-        end_mark = doc.create_mark(None, end)
-
-        if not start.ends_line():
-            start.forward_to_line_end()
-
-        # Include trailing spaces in the chunk to be removed
-        while start.backward_char() and start.get_char() in ('\t', ' '):
-            pass
-        start.forward_char()
-
-        while doc.get_iter_at_mark(end_mark).compare(start) == 1:
-            end = start.copy()
-            while end.get_char() in ('\r', '\n', ' ', '\t'):
-                end.forward_char()
-            doc.delete(start, end)
-
-            doc.insert(start, ' ')
-            start.forward_to_line_end()
-
-        doc.delete_mark(end_mark)
-        doc.end_user_action()
+        doc.join_lines(start, end)
 
     def split_lines(self):
         doc = self.view.get_buffer()
@@ -207,7 +185,7 @@ class JoinLinesViewActivatable(GObject.Object, Gedit.ViewActivatable):
             current_word_end = current_word_start.copy()
             forward_to_word_end(current_word_end)
 
-            if ord(current_word_end.get_char()) and \
+            if (not current_word_end.is_end()) and \
                doc.get_iter_at_mark(end_mark).compare(current_word_end) >= 0:
 
                 word_length = current_word_end.get_offset() - \
@@ -215,7 +193,7 @@ class JoinLinesViewActivatable(GObject.Object, Gedit.ViewActivatable):
 
                 doc.delete(previous_word_end, current_word_start)
 
-                line_offset = self.view.get_visual_line_column(current_word_start)
+                line_offset = self.view.get_visual_column(current_word_start)
                 if line_offset + word_length > width - 1:
                     doc.insert(current_word_start, '\n' + indent)
                 else:
@@ -232,14 +210,14 @@ class JoinLinesViewActivatable(GObject.Object, Gedit.ViewActivatable):
 
 def forward_to_word_start(text_iter):
     char = text_iter.get_char()
-    while ord(char) and (char in (' ', '\t', '\n', '\r')):
+    while not text_iter.is_end() and char in (' ', '\t', '\n', '\r'):
         text_iter.forward_char()
         char = text_iter.get_char()
 
 
 def forward_to_word_end(text_iter):
     char = text_iter.get_char()
-    while ord(char) and (not (char in (' ', '\t', '\n', '\r'))):
+    while not text_iter.is_end() and not (char in (' ', '\t', '\n', '\r')):
         text_iter.forward_char()
         char = text_iter.get_char()
 
