@@ -36,7 +36,7 @@ except:
 class GeditTerminal(Vte.Terminal):
 
     defaults = {
-        'visible_bell'          : False,
+        'audible_bell'          : False,
     }
 
     TARGET_URI_LIST = 200
@@ -144,7 +144,7 @@ class GeditTerminal(Vte.Terminal):
         self.set_allow_bold(self.profile_settings.get_boolean("allow-bold"))
         self.set_scroll_on_keystroke(self.profile_settings.get_boolean("scroll-on-keystroke"))
         self.set_scroll_on_output(self.profile_settings.get_boolean("scroll-on-output"))
-        self.set_visible_bell(self.defaults['visible_bell'])
+        self.set_audible_bell(self.defaults['audible_bell'])
 
         if self.profile_settings.get_boolean("scrollback-unlimited"):
             lines = -1
@@ -160,7 +160,7 @@ class GeditTerminalPanel(Gtk.Box):
 
     __gsignals__ = {
         "populate-popup": (
-            GObject.SIGNAL_RUN_LAST,
+            GObject.SignalFlags.RUN_LAST,
             None,
             (GObject.TYPE_OBJECT,)
         )
@@ -297,7 +297,7 @@ class GeditTerminalPanel(Gtk.Box):
 class TerminalPlugin(GObject.Object, Gedit.WindowActivatable):
     __gtype_name__ = "TerminalPlugin"
 
-    window = GObject.property(type=Gedit.Window)
+    window = GObject.Property(type=Gedit.Window)
 
     def __init__(self):
         GObject.Object.__init__(self)
